BlobRecordHeader

Struct BlobRecordHeader 

pub struct BlobRecordHeader(/* private fields */);
Header word for an FXT Blob record (RecordType = 5).

Implementations

Source

impl BlobRecordHeader

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const BLOB_TYPE_MASK: u64

Unshifted bitmask of blob_type.

pub const BLOB_TYPE_SHIFT: usize = 48

Bit shift (i.e., the low bit) of blob_type.

pub const BLOB_SIZE_MASK: u64

Unshifted bitmask of blob_size.

pub const BLOB_SIZE_SHIFT: usize = 32

Bit shift (i.e., the low bit) of blob_size.

pub const NAME_REF_MASK: u64

Unshifted bitmask of name_ref.

pub const NAME_REF_SHIFT: usize = 16

Bit shift (i.e., the low bit) of name_ref.

pub const RECORD_SIZE_MASK: u64

Unshifted bitmask of record_size.

pub const RECORD_SIZE_SHIFT: usize = 4

Bit shift (i.e., the low bit) of record_size.

pub const RECORD_TYPE_MASK: u64

Unshifted bitmask of record_type.

pub const RECORD_TYPE_SHIFT: usize = 0

Bit shift (i.e., the low bit) of record_type.

pub const RECORD_TYPE_DEFAULT: u64

Pre-shifted default value of the record_type field.

pub const FIELDS: [FieldMetadata<u64>; 5]

Metadata of all named fields in the layout.

pub const fn new() -> BlobRecordHeader

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub fn blob_type(&self) -> BlobType
where BlobType: TryFromBytes,

The value of BlobRecordHeader[55:48].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_blob_type to recover from invalid bit patterns.

pub fn try_blob_type(&self) -> Result<BlobType, InvalidBits<u8>>
where BlobType: TryFromBytes,

Fallible variant of Self::blob_type.

pub fn set_blob_type(&mut self, value: BlobType) -> &mut BlobRecordHeader
where BlobType: IntoBytes + Immutable,

Sets the value of BlobRecordHeader[55:48].

pub const fn blob_size(&self) -> u16

The value of BlobRecordHeader[46:32].

pub const fn set_blob_size(&mut self, value: u16) -> &mut BlobRecordHeader

Sets the value of BlobRecordHeader[46:32].

pub const fn name_ref(&self) -> u16

The value of BlobRecordHeader[31:16].

pub const fn set_name_ref(&mut self, value: u16) -> &mut BlobRecordHeader

Sets the value of BlobRecordHeader[31:16].

pub const fn record_size(&self) -> u16

The value of BlobRecordHeader[15:4].

pub const fn set_record_size(&mut self, value: u16) -> &mut BlobRecordHeader

Sets the value of BlobRecordHeader[15:4].

pub fn record_type(&self) -> RecordType
where RecordType: TryFromBytes,

The value of BlobRecordHeader[3:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_record_type to recover from invalid bit patterns.

pub fn try_record_type(&self) -> Result<RecordType, InvalidBits<u8>>
where RecordType: TryFromBytes,

Fallible variant of Self::record_type.

pub fn set_record_type(&mut self, value: RecordType) -> &mut BlobRecordHeader
where RecordType: IntoBytes + Immutable,

Sets the value of BlobRecordHeader[3:0].

Source

impl BlobRecordHeader

pub fn iter(&self) -> BlobRecordHeaderIter

Returns an iterator over ([metadata][bitrs::FieldMetadata], value) pairs for each field.