pub struct EventRecordHeader(/* private fields */);Expand description
Header word for an FXT Event record (RecordType = 4).
Implementations
Sourceimpl EventRecordHeader
impl EventRecordHeader
Sourcepub const RSVD1_MASK: u64
pub const RSVD1_MASK: u64
Mask of all reserved-as-1 bits.
Sourcepub const RSVD0_MASK: u64
pub const RSVD0_MASK: u64
Mask of all reserved-as-0 bits.
Sourcepub const DEFAULT: u64
pub const DEFAULT: u64
The default value of the layout, combining all field defaults and reserved-as values.
Sourcepub const NAME_REF_MASK: u64
pub const NAME_REF_MASK: u64
Unshifted bitmask of name_ref.
Sourcepub const NAME_REF_SHIFT: usize = 48
pub const NAME_REF_SHIFT: usize = 48
Bit shift (i.e., the low bit) of name_ref.
Sourcepub const CATEGORY_REF_MASK: u64
pub const CATEGORY_REF_MASK: u64
Unshifted bitmask of category_ref.
Sourcepub const CATEGORY_REF_SHIFT: usize = 32
pub const CATEGORY_REF_SHIFT: usize = 32
Bit shift (i.e., the low bit) of category_ref.
Sourcepub const THREAD_REF_MASK: u64
pub const THREAD_REF_MASK: u64
Unshifted bitmask of thread_ref.
Sourcepub const THREAD_REF_SHIFT: usize = 24
pub const THREAD_REF_SHIFT: usize = 24
Bit shift (i.e., the low bit) of thread_ref.
Sourcepub const ARG_COUNT_MASK: u64
pub const ARG_COUNT_MASK: u64
Unshifted bitmask of arg_count.
Sourcepub const ARG_COUNT_SHIFT: usize = 20
pub const ARG_COUNT_SHIFT: usize = 20
Bit shift (i.e., the low bit) of arg_count.
Sourcepub const EVENT_TYPE_MASK: u64
pub const EVENT_TYPE_MASK: u64
Unshifted bitmask of event_type.
Sourcepub const EVENT_TYPE_SHIFT: usize = 16
pub const EVENT_TYPE_SHIFT: usize = 16
Bit shift (i.e., the low bit) of event_type.
Sourcepub const RECORD_SIZE_MASK: u64
pub const RECORD_SIZE_MASK: u64
Unshifted bitmask of record_size.
Sourcepub const RECORD_SIZE_SHIFT: usize = 4
pub const RECORD_SIZE_SHIFT: usize = 4
Bit shift (i.e., the low bit) of record_size.
Sourcepub const RECORD_TYPE_MASK: u64
pub const RECORD_TYPE_MASK: u64
Unshifted bitmask of record_type.
Sourcepub const RECORD_TYPE_SHIFT: usize = 0
pub const RECORD_TYPE_SHIFT: usize = 0
Bit shift (i.e., the low bit) of record_type.
Sourcepub const RECORD_TYPE_DEFAULT: u64
pub const RECORD_TYPE_DEFAULT: u64
Pre-shifted default value of the record_type field.
Sourcepub const fn new() -> EventRecordHeader
pub const fn new() -> EventRecordHeader
Creates a new instance with reserved-as-1 bits set and
all other bits zeroed (i.e., with a value of
Self::RSVD1_MASK).
pub const fn bits(self) -> u64
Sourcepub const fn set_name_ref(&mut self, value: u16) -> &mut EventRecordHeader
pub const fn set_name_ref(&mut self, value: u16) -> &mut EventRecordHeader
Sets the value of EventRecordHeader[63:48].
Sourcepub const fn category_ref(&self) -> u16
pub const fn category_ref(&self) -> u16
The value of EventRecordHeader[47:32].
Sourcepub const fn set_category_ref(&mut self, value: u16) -> &mut EventRecordHeader
pub const fn set_category_ref(&mut self, value: u16) -> &mut EventRecordHeader
Sets the value of EventRecordHeader[47:32].
Sourcepub const fn thread_ref(&self) -> u8
pub const fn thread_ref(&self) -> u8
The value of EventRecordHeader[31:24].
Sourcepub const fn set_thread_ref(&mut self, value: u8) -> &mut EventRecordHeader
pub const fn set_thread_ref(&mut self, value: u8) -> &mut EventRecordHeader
Sets the value of EventRecordHeader[31:24].
Sourcepub const fn set_arg_count(&mut self, value: u8) -> &mut EventRecordHeader
pub const fn set_arg_count(&mut self, value: u8) -> &mut EventRecordHeader
Sets the value of EventRecordHeader[23:20].
Sourcepub fn event_type(&self) -> EventTypewhere
EventType: TryFromBytes,
pub fn event_type(&self) -> EventTypewhere
EventType: TryFromBytes,
The value of EventRecordHeader[19:16].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_event_type to recover from invalid bit patterns.
Sourcepub fn try_event_type(&self) -> Result<EventType, InvalidBits<u8>>where
EventType: TryFromBytes,
pub fn try_event_type(&self) -> Result<EventType, InvalidBits<u8>>where
EventType: TryFromBytes,
Fallible variant of Self::event_type.
Sourcepub fn set_event_type(&mut self, value: EventType) -> &mut EventRecordHeaderwhere
EventType: IntoBytes + Immutable,
pub fn set_event_type(&mut self, value: EventType) -> &mut EventRecordHeaderwhere
EventType: IntoBytes + Immutable,
Sets the value of EventRecordHeader[19:16].
Sourcepub const fn record_size(&self) -> u16
pub const fn record_size(&self) -> u16
The value of EventRecordHeader[15:4].
Sourcepub const fn set_record_size(&mut self, value: u16) -> &mut EventRecordHeader
pub const fn set_record_size(&mut self, value: u16) -> &mut EventRecordHeader
Sets the value of EventRecordHeader[15:4].
Sourcepub fn record_type(&self) -> RecordTypewhere
RecordType: TryFromBytes,
pub fn record_type(&self) -> RecordTypewhere
RecordType: TryFromBytes,
The value of EventRecordHeader[3:0].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_record_type to recover from invalid bit patterns.
Sourcepub fn try_record_type(&self) -> Result<RecordType, InvalidBits<u8>>where
RecordType: TryFromBytes,
pub fn try_record_type(&self) -> Result<RecordType, InvalidBits<u8>>where
RecordType: TryFromBytes,
Fallible variant of Self::record_type.
Sourcepub fn set_record_type(&mut self, value: RecordType) -> &mut EventRecordHeaderwhere
RecordType: IntoBytes + Immutable,
pub fn set_record_type(&mut self, value: RecordType) -> &mut EventRecordHeaderwhere
RecordType: IntoBytes + Immutable,
Sets the value of EventRecordHeader[3:0].