pub struct LogRecordHeader(/* private fields */);Expand description
Header word for an FXT Log record (RecordType = 9).
Implementations
Sourceimpl LogRecordHeader
impl LogRecordHeader
Sourcepub const RSVD1_MASK: u64
pub const RSVD1_MASK: u64
Mask of all reserved-as-1 bits.
Sourcepub const RSVD0_MASK: u64
pub const RSVD0_MASK: u64
Mask of all reserved-as-0 bits.
Sourcepub const DEFAULT: u64
pub const DEFAULT: u64
The default value of the layout, combining all field defaults and reserved-as values.
Sourcepub const THREAD_REF_MASK: u64
pub const THREAD_REF_MASK: u64
Unshifted bitmask of thread_ref.
Sourcepub const THREAD_REF_SHIFT: usize = 32
pub const THREAD_REF_SHIFT: usize = 32
Bit shift (i.e., the low bit) of thread_ref.
Sourcepub const LOG_MESSAGE_LEN_MASK: u64
pub const LOG_MESSAGE_LEN_MASK: u64
Unshifted bitmask of log_message_len.
Sourcepub const LOG_MESSAGE_LEN_SHIFT: usize = 16
pub const LOG_MESSAGE_LEN_SHIFT: usize = 16
Bit shift (i.e., the low bit) of log_message_len.
Sourcepub const RECORD_SIZE_MASK: u64
pub const RECORD_SIZE_MASK: u64
Unshifted bitmask of record_size.
Sourcepub const RECORD_SIZE_SHIFT: usize = 4
pub const RECORD_SIZE_SHIFT: usize = 4
Bit shift (i.e., the low bit) of record_size.
Sourcepub const RECORD_TYPE_MASK: u64
pub const RECORD_TYPE_MASK: u64
Unshifted bitmask of record_type.
Sourcepub const RECORD_TYPE_SHIFT: usize = 0
pub const RECORD_TYPE_SHIFT: usize = 0
Bit shift (i.e., the low bit) of record_type.
Sourcepub const RECORD_TYPE_DEFAULT: u64
pub const RECORD_TYPE_DEFAULT: u64
Pre-shifted default value of the record_type field.
Sourcepub const fn new() -> LogRecordHeader
pub const fn new() -> LogRecordHeader
Creates a new instance with reserved-as-1 bits set and
all other bits zeroed (i.e., with a value of
Self::RSVD1_MASK).
pub const fn bits(self) -> u64
Sourcepub const fn thread_ref(&self) -> u8
pub const fn thread_ref(&self) -> u8
The value of LogRecordHeader[39:32].
Sourcepub const fn set_thread_ref(&mut self, value: u8) -> &mut LogRecordHeader
pub const fn set_thread_ref(&mut self, value: u8) -> &mut LogRecordHeader
Sets the value of LogRecordHeader[39:32].
Sourcepub const fn log_message_len(&self) -> u16
pub const fn log_message_len(&self) -> u16
The value of LogRecordHeader[30:16].
Sourcepub const fn set_log_message_len(&mut self, value: u16) -> &mut LogRecordHeader
pub const fn set_log_message_len(&mut self, value: u16) -> &mut LogRecordHeader
Sets the value of LogRecordHeader[30:16].
Sourcepub const fn record_size(&self) -> u16
pub const fn record_size(&self) -> u16
The value of LogRecordHeader[15:4].
Sourcepub const fn set_record_size(&mut self, value: u16) -> &mut LogRecordHeader
pub const fn set_record_size(&mut self, value: u16) -> &mut LogRecordHeader
Sets the value of LogRecordHeader[15:4].
Sourcepub fn record_type(&self) -> RecordTypewhere
RecordType: TryFromBytes,
pub fn record_type(&self) -> RecordTypewhere
RecordType: TryFromBytes,
The value of LogRecordHeader[3:0].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_record_type to recover from invalid bit patterns.
Sourcepub fn try_record_type(&self) -> Result<RecordType, InvalidBits<u8>>where
RecordType: TryFromBytes,
pub fn try_record_type(&self) -> Result<RecordType, InvalidBits<u8>>where
RecordType: TryFromBytes,
Fallible variant of Self::record_type.
Sourcepub fn set_record_type(&mut self, value: RecordType) -> &mut LogRecordHeaderwhere
RecordType: IntoBytes + Immutable,
pub fn set_record_type(&mut self, value: RecordType) -> &mut LogRecordHeaderwhere
RecordType: IntoBytes + Immutable,
Sets the value of LogRecordHeader[3:0].